summaryrefslogtreecommitdiffstats
path: root/ksirc/puke/pkfiledialog.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /ksirc/puke/pkfiledialog.cpp
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ksirc/puke/pkfiledialog.cpp')
-rw-r--r--ksirc/puke/pkfiledialog.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/ksirc/puke/pkfiledialog.cpp b/ksirc/puke/pkfiledialog.cpp
index f78ae895..255ed2b8 100644
--- a/ksirc/puke/pkfiledialog.cpp
+++ b/ksirc/puke/pkfiledialog.cpp
@@ -9,22 +9,22 @@
PObject *
PKFileDialog::createWidget(CreateArgs &ca)
{
- PKFileDialog *pw = new PKFileDialog(ca.parent);
+ PKFileDialog *pw = new PKFileDialog(ca.tqparent);
KFileDialog *kfbd;
if(ca.fetchedObj != 0 && ca.fetchedObj->inherits("KFileDialog") == TRUE){
kfbd = (KFileDialog *) ca.fetchedObj;
pw->setDeleteAble(FALSE);
}
- else // Never takes a parent in Puke
- kfbd = new KFileDialog("/", TQString::null, 0L, "PukeKFileDialog", TRUE);
+ else // Never takes a tqparent in Puke
+ kfbd = new KFileDialog("/", TQString(), 0L, "PukeKFileDialog", TRUE);
pw->setWidget(kfbd);
pw->setWidgetId(ca.pwI);
return pw;
}
-PKFileDialog::PKFileDialog(PObject *parent)
- : PWidget(parent)
+PKFileDialog::PKFileDialog(PObject *tqparent)
+ : PWidget(tqparent)
{
kfbd = 0;
setWidget(kfbd);